
from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .actionlist import ActionList
    from .application import Application
    from .actionreference import ActionReference
    from .psdescvaluetype import PsDescValueType

class ActionDescriptor():
    """
    A record of key-value pairs for actions, such as those included on the Adobe Photoshop Actions menu. Note: The ActionDescriptor class is part of the Action Manager functionality. See the Photoshop Scripting Guide.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Count(self) -> int:
        """
        Read-only. The number of keys contained in the descriptor.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced ActionDescriptor object.
        """
        ...

    def Clear(self) -> None:
        """
        Clears the descriptor.
        """
        ...

    def Erase(self, Key:int) -> None:
        """
        Erases a key from the descriptor.
        """
        ...

    def GetBoolean(self, Key:int) -> bool:
        """
        Gets the value of a key of type boolean.
        """
        ...

    def GetClass(self, Key:int) -> int:
        """
        Gets the value of a key of type class.
        """
        ...

    def GetDouble(self, Key:int) -> float:
        """
        Gets the value of a key of type double.
        """
        ...

    def GetEnumerationType(self, Key:int) -> int:
        """
        Gets the enumeration type of a key.
        """
        ...

    def GetEnumerationValue(self, Key:int) -> int:
        """
        Gets the enumeration value of a key.
        """
        ...

    def GetInteger(self, Key:int) -> int:
        """
        Gets the value of a key of type integer.
        """
        ...

    def GetKey(self, Index:int) -> int:
        """
        Gets the ID of the Nth key.
        """
        ...

    def GetLargeInteger(self, Key:int) -> int:
        """
        Gets the value of a key of type large integer.
        """
        ...

    def GetList(self, Key:int) -> ActionList:
        """
        Gets the value of a key of type list.
        """
        ...

    def GetObjectType(self, Key:int) -> int:
        """
        Gets the class ID of an object in a key of type object.
        """
        ...

    def GetObjectValue(self, Key:int):
        """
        Gets the value of a key of type object.
        """
        ...

    def GetPath(self, Key:int) -> str:
        """
        Gets the value of a key of type Alias. Returns a String that represents a file path.
        """
        ...

    def GetReference(self, Key:int) -> ActionReference:
        """
        Gets the value of a key of type ActionReference.
        """
        ...

    def GetString(self, Key:int) -> str:
        """
        Gets the value of a key of type String.
        """
        ...

    def GetType(self, Key:int) -> PsDescValueType:
        """
        Gets the type of a key.
        """
        ...

    def GetUnitDoubleType(self, Key:int) -> int:
        """
        Gets the unit type of a key of type UnitDouble.
        """
        ...

    def GetUnitDoubleValue(self, Key:int) -> float:
        """
        Gets the value of a key of type UnitDouble.
        """
        ...

    def HasKey(self, Key:int) -> bool:
        """
        Checks whether the descriptor contains the provided key.
        """
        ...

    def IsEqual(self, otherDesc) -> bool:
        """
        Determines whether the descriptor is the same as another descriptor.
        """
        ...

    def PutBoolean(self, Key:int, Value:bool) -> None:
        """
        Sets the value for a key whose type is Boolean.
        """
        ...

    def PutClass(self, Key:int, Value:int) -> None:
        """
        Sets the value for a key whose type is class.
        """
        ...

    def PutDouble(self, Key:int, Value:float) -> None:
        """
        Sets the value for a key whose type is double.
        """
        ...

    def PutEnumerated(self, Key:int, EnumType:int, Value:int) -> None:
        """
        Sets the enumeration type and value for a key.
        """
        ...

    def PutInteger(self, Key:int, Value:int) -> None:
        """
        Sets the value for a key whose type is integer.
        """
        ...

    def PutLargeInteger(self, Key:int, Value:int) -> None:
        """
        Sets the value for a key whose type is large integer.
        """
        ...

    def PutList(self, Key:int, Value:ActionList) -> None:
        """
        Sets the value for a key whose type is an ActionList object.
        """
        ...

    def PutObject(self, Key:int, ClassID:int, Value) -> None:
        """
        Sets the value for a key whose type is an Action Descriptor.
        """
        ...

    def PutPath(self, Key:int, Value:str) -> None:
        """
        Sets the value for a key whose type is path. The Value argument takes a String that represents a file path.
        """
        ...

    def PutReference(self, Key:int, Value:ActionReference) -> None:
        """
        Sets the value for a key whose type is an object reference.
        """
        ...

    def PutString(self, Key:int, Value:str) -> None:
        """
        Sets the value for a key whose type is String.
        """
        ...

    def PutUnitDouble(self, Key:int, UnitID:int, Value:float) -> None:
        """
        Sets the value for a key whose type is a unit value formatted as a double.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .psillustratorpathtype import PsIllustratorPathType

class ExportOptionsIllustrator():
    """
    Options that can be specified when exporting a PathItem object to an Adobe Illustrator® file. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Path(self) -> PsIllustratorPathType:
        """
        Read-write. The type of path to export. Default: 1.
        """
        ...

    @property
    def PathName(self) -> str:
        """
        Read-write. The name of the path to export. Note:Valid only when Path = 3. See Path.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced ExportOptionsIllustrator object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .rgbcolor import RGBColor
    from .application import Application
    from .psgallerysecuritytextrotatetype import PsGallerySecurityTextRotateType
    from .psgallerysecuritytextpositiontype import PsGallerySecurityTextPositionType
    from .psnewdocumentmode import PsNewDocumentMode
    from .psgalleryfonttype import PsGalleryFontType
    from .pspicturepackagetexttype import PsPicturePackageTextType

class PicturePackageOptions():
    """
    Options that can be specified for a Picture Package.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Content(self) -> PsPicturePackageTextType:
        """
        Read-write. The content information. Default: 0 (psNoText).
        """
        ...

    @property
    def Flatten(self) -> bool:
        """
        Read-write. Indicates whether all layers in the final document are flattened. Default: true.
        """
        ...

    @property
    def Font(self) -> PsGalleryFontType:
        """
        Read-write. The font used for security text. Default: 1 (psArial).
        """
        ...

    @property
    def FontSize(self) -> int:
        """
        Read-write. The font size used for security text. Default: 12.
        """
        ...

    @property
    def Layout(self) -> str:
        """
        Read-write. The layout to use to generate the picture package. Default: “(2)5x7”.
        """
        ...

    @property
    def Mode(self) -> PsNewDocumentMode:
        """
        Read-write. Read-write. The color profile to use as the document mode. Default: 2 (psNewRGB).
        """
        ...

    @property
    def Opacity(self) -> int:
        """
        Read-write. The Web page security opacity as a percent. Default: 100.
        """
        ...

    @property
    def Resolution(self) -> float:
        """
        Read-write. The resolution of the document in pixels per inch. Default: 72.0.
        """
        ...

    @property
    def Text(self) -> str:
        """
        Read-write. The picture package custom text. Note:Valid only when Content = 2 (psUserText). See Content.
        """
        ...

    @property
    def TextColor(self) -> RGBColor:
        """
        Read-write. The color to use for security text.
        """
        ...

    @property
    def TextPosition(self) -> PsGallerySecurityTextPositionType:
        """
        Read-write. The security text position. Default: 1 (psCentered).
        """
        ...

    @property
    def TextRotate(self) -> PsGallerySecurityTextRotateType:
        """
        Read-write. The orientation to use for security text. Default: 1 (psZero).
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced PicturePackageOptions object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .psgalleryfonttype import PsGalleryFontType

class GalleryBannerOptions():
    """
    Options that define the BannerOptions property of the GalleryOptions object. See ‘GalleryOptions ’ on page 82.Tip: You can preserve default values for many GalleryBannerOptions properties by setting the GalleryOptions property PreserveAllMetadata to true or by choosing File > Automate > Web Photo Gallery , and then choosing Preserve all metadata on the Options area of the Web Photo Gallery dialog. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def ContactInfo(self) -> str:
        """
        Read-write. The Web photo gallery contact info.
        """
        ...

    @property
    def Date(self) -> str:
        """
        Read-write. The Web photo gallery date. Default: current date.
        """
        ...

    @property
    def Font(self) -> PsGalleryFontType:
        """
        Read-write. The font setting for the banner text. Default: 1.
        """
        ...

    @property
    def FontSize(self) -> int:
        """
        Read-write. The font size for the banner text (1 - 7; default: 3).
        """
        ...

    @property
    def Photographer(self) -> str:
        """
        Read-write. The Web photo gallery photographer.
        """
        ...

    @property
    def SiteName(self) -> str:
        """
        Read-write. The Web photo gallery site name. Default: Adobe Web Photo Gallery.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced GalleryBannerOptions object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application

class Notifier():
    """
    An event-handler object that tells the script to ex ecute specified code when a specified event occurs. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Event(self) -> str:
        """
        Read-only. The event ID in four characters or a unique String that the notifier is associated with. Note:For a list of four-character codes, see Appendix A: Event ID Codes.
        """
        ...

    @property
    def EventClass(self) -> str:
        """
        Read-only. The class ID of the event associated with the Notifier object, four characters or a unique string. Note:When an event applies to multiple types of objects, you use this propety to distinguish which object this Notifier applies to. For example, the Make event (“Mk “)applies to documents (“Dcmn”), channels (“Chnl”) and other objects..
        """
        ...

    @property
    def EventFile(self) -> str:
        """
        Read-only. The path to the file to execute when the event occurs/activates the notifier.
        """
        ...

    @property
    def Parent(self) -> Application:
        """
        Read-only. The Notifier object’s container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced Notifier object.
        """
        ...

    def Remove(self) -> None:
        """
        Deletes the Notifier object. Note:You can remove a Notifier object from the Script Events Manager drop-down list by deleting the file named Script Events Manager.xml from in the Photoshop preferences folder. See Adobe Photoshop help for more information.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .hsbcolor import HSBColor
    from .application import Application
    from .rgbcolor import RGBColor
    from .labcolor import LabColor
    from .cmykcolor import CMYKColor
    from .graycolor import GrayColor
    from .pscolormodel import PsColorModel

class SolidColor():
    """
    A color definition used in the document. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def CMYK(self) -> CMYKColor:
        """
        Read-write. The CMYK color mode.
        """
        ...

    @property
    def Gray(self) -> GrayColor:
        """
        Read-write. The Grayscale color mode.
        """
        ...

    @property
    def HSB(self) -> HSBColor:
        """
        Read-write. The HSB color mode.
        """
        ...

    @property
    def Lab(self) -> LabColor:
        """
        Read-write. The LAB color mode.
        """
        ...

    @property
    def Model(self) -> PsColorModel:
        """
        Read-write. The color model.
        """
        ...

    @property
    def NearestWebColor(self) -> RGBColor:
        """
        Read-only. The nearest Web color to the current color.
        """
        ...

    @property
    def RGB(self) -> RGBColor:
        """
        Read-write. The RGB color mode.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced SolidColor object.
        """
        ...

    def IsEqual(self, Color) -> bool:
        """
        Indicates whether the SolidColor object is visually equal to the specified color.
        """
        ...




class PsAdjustmentReference():
    """
    Method to use for interpreting selective color adjustment specifications: 1 = % of the existing color amount; 2 = % of the whole.
    """
    psRelative = 1
    psAbsolute = 2

class PsAnchorPosition():
    """
    The point on the object that does not move when the object is rotated or resized.
    """
    psTopLeft = 1
    psTopCenter = 2
    psTopRight = 3
    psMiddleLeft = 4
    psMiddleCenter = 5
    psMiddleRight = 6
    psBottomLeft = 7
    psBottomCenter = 8
    psBottomRight = 9

class PsAntiAlias():
    """
    Method to use to smooth edges by softening the color transition between edge pixels and background pixels.
    """
    psNoAntialias = 1
    psSharp = 2
    psCrisp = 3
    psStrong = 4
    psSmooth = 5

class PsAutoKernType():
    """
    The type of kerning to use for characters.
    """
    psManual = 1
    psMetrics = 2
    psOptical = 3

class PsBatchDestinationType():
    """
    The destination, if any, for batch-processed files: 1: Leave all files open; 2: Save changes and close the files; 3: Save modified versions of the files to a new location (leaving the originals unchanged).
    """
    psNoDestination = 1
    psSaveAndClose = 2
    psFolder = 3

class PsBitmapConversionType():
    """
    Specifies the quality of an image you are converting to bitmap mode.
    """
    psHalfThreshold = 1
    psPatternDither = 2
    psDiffusionDither = 3
    psHalftoneScreen = 4
    psCustomPattern = 5

class PsBitmapHalfToneType():
    """
    Specifies the shape of the dots (ink deposits) in the halftone screen.
    """
    psHalftoneRound = 1
    psHalftoneDiamond = 2
    psHalftoneEllipse = 3
    psHalftoneLine = 4
    psHalftoneSquare = 5
    psHalftoneCross = 6

class PsBitsPerChannelType():
    """
    The number of bits per color channel.
    """
    psDocument1Bit = 1
    psDocument8Bits = 8
    psDocument16Bits = 16
    psDocument32Bits = 32

class PsBlendMode():
    """
    Controls how pixels in the image are blended.
    """
    psPassThrough = 1
    psNormalBlend = 2
    psDissolve = 3
    psDarken = 4
    psMultiply = 5
    psColorBurn = 6
    psLinearBurn = 7
    psLighten = 8
    psScreen = 9
    psColorDodge = 10
    psLinearDodge = 11
    psOverlay = 12
    psSoftLight = 13
    psHardLight = 14
    psVividLight = 15
    psLinearLight = 16
    psPinLight = 17
    psDifference = 18
    psExclusion = 19
    psHue = 20
    psSaturationBlend = 21
    psColorBlend = 22
    psLuminosity = 23
    psHardMix = 26
    psLighterColor = 27
    psDarkerColor = 28
    psSubtract = 29
    psDivide = 30

class PsBMPDepthType():
    """
    The number of bits per channel (also called pixel depth or color depth). The number selected indicates the exponent of 2. For example, a pixel with a bit-depth of 8 has 28, or 256, possible color values.
    """
    psBMP1Bit = 1
    psBMP4Bits = 4
    psBMP8Bits = 8
    psBMP16Bits = 16
    psBMP24Bits = 24
    psBMP32Bits = 32
    psBMP_X1R5G5B5 = 60
    psBMP_A1R5G5B5 = 61
    psBMP_R5G6B5 = 62
    psBMP_X4R4G4B4 = 63
    psBMP_A4R4G4B4 = 64
    psBMP_R8G8B8 = 65
    psBMP_X8R8G8B8 = 66
    psBMP_A8R8G8B8 = 67

class PsByteOrder():
    """
    The order in which bytes will be read.
    """
    psIBMByteOrder = 1
    psMacOSByteOrder = 2

class PsCameraRAWSettingsType():
    """
    The default CameraRAW settings to use: the camera settings, custom settings, or the settings of the selected image.
    """
    psCameraDefault = 0
    psSelectedImage = 1
    psCustomSettings = 2

class PsCameraRAWSize():
    """
    The camera RAW size type options: 0 = 1536 x 1024 1 = 2048 x 1365 2 = 3072 x 2048 3 = 4096 x 2731 4 = 5120 x 4096 5 = 6144 x 4096
    """
    psMinimumCameraRAW = 0
    psSmallCameraRAW = 1
    psMediumCameraRAW = 2
    psLargeCameraRAW = 3
    psExtraLargeCameraRAW = 4
    psMaximumCameraRAW = 5

class PsCase():
    """
    The case usage for type.
    """
    psNormalCase = 1
    psAllCaps = 2
    psSmallCaps = 3

class PsChangeMode():
    """
    The type of color mode to use. Note:Color images must be changed to grayscale (1) mode before you can change them to bitmap (5) mode.
    """
    psConvertToGrayscale = 1
    psConvertToRGB = 2
    psConvertToCMYK = 3
    psConvertToLab = 4
    psConvertToBitmap = 5
    psConvertToIndexedColor = 6
    psConvertToMultiChannel = 7

class PsChannelType():
    """
    The type of channel: 1: related to document color mode; 2: Alpha channel where color indicates masked area; 3: Alpha channel where color indicates selected area; 4: channel that contains spot colors.
    """
    psComponentChannel = 1
    psMaskedAreaAlphaChannel = 2
    psSelectedAreaAlphaChannel = 3
    psSpotColorChannel = 4

class PsColorBlendMode():
    """
    Controls how pixels in the image are blended.
    """
    psNormalBlendColor = 2
    psDissolveBlend = 3
    psDarkenBlend = 4
    psMultiplyBlend = 5
    psColorBurnBlend = 6
    psLinearBurnBlend = 7
    psLightenBlend = 8
    psScreenBlend = 9
    psColorDodgeBlend = 10
    psLinearDodgeBlend = 11
    psOverlayBlend = 12
    psSoftLightBlend = 13
    psHardLightBlend = 14
    psVividLightBlend = 15
    psLinearLightBlend = 16
    psPinLightBlend = 17
    psDifferenceBlend = 18
    psExclusionBlend = 19
    psHueBlend = 20
    psClearBlend = 25
    psHardMixBlend = 26
    psSubtract = 27
    psDivide = 28

class PsColorModel():
    """
    The color model to use.
    """
    psGrayscaleModel = 1
    psRGBModel = 2
    psCMYKModel = 3
    psLabModel = 4
    psHSBModel = 5
    psNoModel = 50

class PsColorPicker():
    """
    The color picker to use.
    """
    psAdobeColorPicker = 1
    psAppleColorPicker = 2
    psWindowsColorPicker = 3
    psPlugInColorPicker = 4

class PsColorProfileType():
    """
    The color profile type to use to manage this document.
    """
    psNo = 1
    psWorking = 2
    psCustom = 3

class PsColorReductionType():
    """
    The color reduction algorithm option to use.
    """
    psPerceptualReduction = 0
    psSelective = 1
    psAdaptive = 2
    psRestrictive = 3
    psCustomReduction = 4
    psBlackWhiteReduction = 5
    psSFWGrayscale = 6
    psMacintoshColors = 7
    psWindowsColors = 8

class PsColorSpaceType():
    """
    The type of color space to use.
    """
    psAdobeRGB = 0
    psColorMatchRGB = 1
    psProPhotoRGB = 2
    psSRGB = 3

class PsCopyrightedType():
    """
    The copyright status of the document.
    """
    psCopyrightedWork = 1
    psPublicDomain = 2
    psUnmarked = 3

class PsCreateFields():
    """
    The method to use for creating fields.
    """
    psDuplication = 1
    psInterpolation = 2




class PsAdjustmentReference():
    """
    Method to use for interpreting selective color adjustment specifications: 1 = % of the existing color amount; 2 = % of the whole.
    """
    psRelative = 1
    psAbsolute = 2

class PsAnchorPosition():
    """
    The point on the object that does not move when the object is rotated or resized.
    """
    psTopLeft = 1
    psTopCenter = 2
    psTopRight = 3
    psMiddleLeft = 4
    psMiddleCenter = 5
    psMiddleRight = 6
    psBottomLeft = 7
    psBottomCenter = 8
    psBottomRight = 9

class PsAntiAlias():
    """
    Method to use to smooth edges by softening the color transition between edge pixels and background pixels.
    """
    psNoAntialias = 1
    psSharp = 2
    psCrisp = 3
    psStrong = 4
    psSmooth = 5

class PsAutoKernType():
    """
    The type of kerning to use for characters.
    """
    psManual = 1
    psMetrics = 2
    psOptical = 3

class PsBatchDestinationType():
    """
    The destination, if any, for batch-processed files: 1: Leave all files open; 2: Save changes and close the files; 3: Save modified versions of the files to a new location (leaving the originals unchanged).
    """
    psNoDestination = 1
    psSaveAndClose = 2
    psFolder = 3





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .psurgency import PsUrgency
    from .application import Application
    from .document import Document
    from .pscopyrightedtype import PsCopyrightedType

class DocumentInfo():
    """
    Metadata about a Document object. These values can be set by choosing File > File Info in the Adobe Photoshop application. Note: The DocumentInfo object corresponds to the Info property of the Application object. You use the property name Info , rather thanthe object name, DocumentInfo , in a script, as in the following sample, which sets the Author , Caption , and Copyrighted properties:Dim docRefdocRef = Open(fileList[i])' set the file infodocRef.Info.Author = "Mr. Adobe Programmer"docRef.Info.Caption = "Adobe photo shoot"docRef.Info.Copyrighted = 1The following sample uses the DocumentInfo object incorrectly:docRef.DocumentInfo.Author = "Mr. Adobe Programmer"docRef.DocumentInfo.Caption = "Adobe photo shoot"docRef.DocumentInfo.Copyrighted = 1
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Author(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def authorPosition(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def Caption(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def CaptionWriter(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def Category(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def City(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def Copyrighted(self) -> PsCopyrightedType:
        """
        Read-write. The copyrighted status.
        """
        ...

    @property
    def CopyrightNotice(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def Country(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def CreationDate(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def Credit(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def EXIF(self) -> list:
        """
        Read-only. Camera data that includes camera settings used when the image was taken. Sample array values are: tag = “camera”; tag value = “Cannon”.
        """
        ...

    @property
    def Headline(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def Instructions(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def JobName(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def Keywords(self) -> List[str]:
        """
        Read-write. A list of keywords that can identify the document or its contents.
        """
        ...

    @property
    def OwnerUrl(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The Info object's container.
        """
        ...

    @property
    def ProvinceState(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def Source(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def SupplementalCategories(self) -> List[str]:
        """
        Read-write.
        """
        ...

    @property
    def Title(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def TransmissionReference(self) -> str:
        """
        Read-write.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced Info object.
        """
        ...

    @property
    def Urgency(self) -> PsUrgency:
        """
        Read-write.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .pslayercompressiontype import PsLayerCompressionType
    from .psbyteorder import PsByteOrder
    from .application import Application
    from .pstiffencodingtype import PsTIFFEncodingType

class TiffSaveOptions():
    """
    Options that can be specified when saving a document in TIFF format. 
    """
    @property
    def AlphaChannels(self) -> bool:
        """
        Read-write. Indicates whether to save the alpha channels.
        """
        ...

    @property
    def Annotations(self) -> bool:
        """
        Read-write. Indicates whether to save the annotations.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def ByteOrder(self) -> PsByteOrder:
        """
        Read-write. The order in which the document’s bytes will be read. The default is 2 (psMacOSByteOrder) when running on Mac OS and 1 (psIBMByteOrder) when running on a PC.
        """
        ...

    @property
    def EmbedColorProfile(self) -> bool:
        """
        Read-write. Indicates whether to embed the color profile in the document.
        """
        ...

    @property
    def ImageCompression(self) -> PsTIFFEncodingType:
        """
        Read-write. The compression type. Default: 1 (psNoTIFFCompression).
        """
        ...

    @property
    def InterleaveChannels(self) -> bool:
        """
        Read-write. Indicates whether the channels in the image will be interleaved.
        """
        ...

    @property
    def JPEGQuality(self) -> int:
        """
        Read-write. The quality of the produced image (0 - 12), which is inversely proportionate to the amount of JPEG compression. Note:Valid only when ImageCompression = 3 (psTiffJPEG).
        """
        ...

    @property
    def LayerCompression(self) -> PsLayerCompressionType:
        """
        Read-write. The method of compression to use when saving layers (as opposed to saving composite data). Note:Valid only when Layers = true. See Layers
        """
        ...

    @property
    def Layers(self) -> bool:
        """
        Read-write. Indicates whether to save the layers.
        """
        ...

    @property
    def SaveImagePyramid(self) -> bool:
        """
        Read-write. Indicates whether to preserve multiresolution information. Default: false.
        """
        ...

    @property
    def SpotColors(self) -> bool:
        """
        Read-write. Indicates whether to save the spot colors.
        """
        ...

    @property
    def Transparency(self) -> bool:
        """
        Read-write. Indicates whether to save the transparency as an additional alpha channel when the file is opened in another application.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced TIFFSaveOptions object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .psnewdocumentmode import PsNewDocumentMode
    from .psgalleryfonttype import PsGalleryFontType

class ContactSheetOptions():
    """
    Options that can be specified for a contact sheet. 
    """
    @property
    def AcrossFirst(self) -> bool:
        """
        Read-write. Indicates whether to place the images horizontally (left to right, then top to bottom) first. Default: true.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def BestFit(self) -> bool:
        """
        Read-write. Indicates whether to rotate images for the best fit. Default: false.
        """
        ...

    @property
    def Caption(self) -> bool:
        """
        Read-write. Indicates whether to use the filename as a caption for the image. Default: true.
        """
        ...

    @property
    def ColumnCount(self) -> int:
        """
        Read-write. The number of columns to include (1 - 100; default: 5).
        """
        ...

    @property
    def Flatten(self) -> bool:
        """
        Read-write. Indicates whether to flatten all layers in the final document. Default: true.
        """
        ...

    @property
    def Font(self) -> PsGalleryFontType:
        """
        Read-write. The font used for the caption. Default: 1.
        """
        ...

    @property
    def FontSize(self) -> int:
        """
        Read-write. The font size to use for the caption. Default: 12.
        """
        ...

    @property
    def Height(self) -> int:
        """
        Read-write. The height (in pixels) of the resulting document (100 - 2900; default: 720).
        """
        ...

    @property
    def Horizontal(self) -> int:
        """
        Read-write. The horizontal spacing (in pixels) between images (0 - 29000; default: 1).
        """
        ...

    @property
    def Mode(self) -> PsNewDocumentMode:
        """
        Read-write. The document color mode. Default: 2 (psNewRGB).
        """
        ...

    @property
    def Resolution(self) -> float:
        """
        Read-write. The resolution of the document in pixels per inch (35 - 1200; default: 72.0).
        """
        ...

    @property
    def RowCount(self) -> int:
        """
        Read-write. The number of rows to use (1 - 100; default: 6).
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced ContactSheetOptions object.
        """
        ...

    @property
    def UseAutoSpacing(self) -> bool:
        """
        Read-write. Indicates whether to auto space the images. Default: true.
        """
        ...

    @property
    def Vertical(self) -> int:
        """
        Read-write. The vertical spacing (in pixels) between images (0 - 29000; default: 1). Note:Valid only when UseAutoSpacing = false.
        """
        ...

    @property
    def Width(self) -> int:
        """
        Read-write. The width (in pixels) of the resulting document (100 - 2900; default: 576).
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .solidcolor import SolidColor
    from .document import Document

class ColorSampler():
    """
    A color sampler for the document. Note: For additional information about color sample rs, see Adobe Photoshop help on the Color SamplerTool. 
    """
    @property
    def Color(self) -> SolidColor:
        """
        Read-only. The color of the color sampler.
        """
        ...

    @property
    def Position(self) -> List[float]:
        """
        Read-only. The position of the color sampler in the document.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The ColorSampler object’s container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced ColorSampler object.
        """
        ...

    def Move(self, position:List[float]) -> None:
        """
        Moves the color sampler to a new location in the document. The position parameter (x,y) represents the new horizontal and vertical locations, respectively, of the moved color sampler.
        """
        ...

    def Delete(self) -> None:
        """
        Deletes the ColorSampler object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .psshapeoperation import PsShapeOperation
    from .pathpoint import PathPoint

class SubPathInfo():
    """
    An array of PathPointInfo objects that describes a straight or curved segment of a path. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Closed(self) -> bool:
        """
        Read-write. Indicates whether the path describes an enclosed area.
        """
        ...

    @property
    def EntireSubPath(self) -> List[PathPoint]:
        """
        Read-write.
        """
        ...

    @property
    def Operation(self) -> PsShapeOperation:
        """
        Read-write. The sub path’s operation on other sub paths.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced SubPathInfo object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application

class TextFont():
    """
    Details about a font in the TextFonts collection. Note: See TextFonts for more information on the TextFonts collection.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Family(self) -> str:
        """
        Read-only. The font family.
        """
        ...

    @property
    def Name(self) -> str:
        """
        Read-only. The name of the font.
        """
        ...

    @property
    def Parent(self) -> Application:
        """
        Read-only. The object's container.
        """
        ...

    @property
    def PostScriptName(self) -> str:
        """
        Read-only. The PostScript name of the font.
        """
        ...

    @property
    def Style(self) -> str:
        """
        Read-only. The font style.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced TextFont object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .textfont import TextFont

class TextFonts():
    """
    The collection of fonts available on your computer.Note: The TextFonts object corresponds to the Fonts property of the Application object. In a script, you use Fonts to refer to a TextFonts object. The following sample demonstrates how to use the Count property of the TextFonts object to display a dialog that indicates the number of fonts installed on the machine. ?Correct:Alert appRef.Fonts.Count?Incorrect:Alert appRef.TextFonts.CountSee ‘Application ’ on page 16’ , specifically the Fonts property, for more information. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def Count(self) -> int:
        """
        Read-only. The number of elements in the TextFonts collection.
        """
        ...

    @property
    def Parent(self) -> Application:
        """
        Read-only. The object's container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced TextFonts object.
        """
        ...

    def Index(self, ItemPtr:TextFont) -> int:
        """
        Gets the index of the TextFont into the collection.
        """
        ...

    def Item(self, ItemKey:int) -> TextFont:
        """
        Gets an element from the TextFonts collection.
        """
        ...




"""
Pypi deployment guide :

pip install setuptools, wheel, twine

py setup.py sdist bdist_wheel
twine upload dist/*
user : __token__
password : <upload_token>
"""

from setuptools import setup
import os

here = os.path.abspath(os.path.dirname(__file__))

VERSION = '0.0.3'
DESCRIPTION = 'Photoshop Object Model'
LONG_DESCRIPTION = r"""
This package is designed to provide autocompletion, access to docstrings, and accurate type hints in your preferred IDE.

All classes have been written based on Photoshop's VBS documentation, which can be found at <https://github.com/Adobe-CEP/CEP-Resources/blob/master/Documentation/Product%20specific%20Documentation/Photoshop%20Scripting/photoshop-vbs-ref-2020.pdf>.
As such, the code you'll find here isn't very pythonic, because it is based on the Visual Basic syntax.
Please note that this package may contain inconsistencies, missing return types, and typos. Unfortunately, most of these issues stem from faithfully transcribing Adobes's flawed documentation.
"""

# Setting up
setup(
    name="photoshop-object-model",
    version=VERSION,
    author="Tristan Languebien",
    author_email="<tlanguebien@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=['photoshop_object_model'],
    install_requires=[],
    keywords=['python', 'photoshop'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Microsoft :: Windows",
    ]
)



from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .psbitsperchanneltype import PsBitsPerChannelType
    from .pscroptotype import PsCropToType
    from .double import Double
    from .application import Application
    from .psopendocumentmode import PsOpenDocumentMode

class PDFOpenOptions():
    """
    Options that can be specified when open ing a document in generic PDF format. 
    """
    @property
    def AntiAlias(self) -> bool:
        """
        Read-write. Indicates whether to use antialias.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def BitsPerChannel(self) -> PsBitsPerChannelType:
        """
        Read-write. The number of bits per channel.
        """
        ...

    @property
    def ConstrainProportions(self) -> bool:
        """
        Deprecated for Adobe Photoshop.
        """
        ...

    @property
    def CropPage(self) -> PsCropToType:
        """
        Read-write. The method of cropping to use.
        """
        ...

    @property
    def Height(self) -> Double:
        """
        Deprecated for Adobe Photoshop.
        """
        ...

    @property
    def Mode(self) -> PsOpenDocumentMode:
        """
        Read-write. The color model to use.
        """
        ...

    @property
    def Name(self) -> str:
        """
        Read-write. The name of the document.
        """
        ...

    @property
    def Object(self) -> int:
        """
        Read-write. The number of 3d objects to open.
        """
        ...

    @property
    def Page(self) -> int:
        """
        Read-write. The page to which to open the document.
        """
        ...

    @property
    def Resolution(self) -> float:
        """
        Read-write. The resolution of the document (in pixels per inch).
        """
        ...

    @property
    def SuppressWarnings(self) -> bool:
        """
        Read-write. Indicates whether to suppress warnings when opening the document.
        """
        ...

    @property
    def Typename(self) -> str:
        """
        Read-only. The class name of the referenced PDFOpenOptions object.
        """
        ...

    @property
    def Use3DObjectNumber(self) -> bool:
        """
        Read-write. If true, the 3d property refers to using 3d object; if false, then UsePageNumber is used.
        """
        ...

    @property
    def UsePageNumber(self) -> bool:
        """
        Read-write. Indicates whether the value specified in the page property will refer to an image number when usePageNumber = false. See Page.
        """
        ...

    @property
    def Width(self) -> Double:
        """
        Deprecated for Adobe Photoshop.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .pscamerarawsize import PsCameraRAWSize
    from .psbitsperchanneltype import PsBitsPerChannelType
    from .pscamerarawsettingstype import PsCameraRAWSettingsType
    from .application import Application
    from .pswhitebalancetype import PsWhiteBalanceType
    from .pscolorspacetype import PsColorSpaceType

class CameraRAWOpenOptions():
    """
    Options that can be specified when opening a document in Camera Raw format.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def BitsPerChannel(self) -> PsBitsPerChannelType:
        """
        Read-write. The number of bits per channel.
        """
        ...

    @property
    def BlueHue(self) -> int:
        """
        Read-write. The blue hue of the shot (-100 - 100).
        """
        ...

    @property
    def BlueSaturation(self) -> int:
        """
        Read-write. The blue saturation of the shot (-100 - 100).
        """
        ...

    @property
    def Brightness(self) -> int:
        """
        Read-write. The brightness of the shot (0 - 150).
        """
        ...

    @property
    def ChromaticAberrationBY(self) -> int:
        """
        Read-write. The chromatic aberration B/Y of the shot (-100 - 100).
        """
        ...

    @property
    def ChromaticAberrationRC(self) -> int:
        """
        Read-write. The chromatic aberration R/C of the shot (-100 - 100).
        """
        ...

    @property
    def ColorNoiseReduction(self) -> int:
        """
        Read-write. The color noise reduction of the shot (0 - 100).
        """
        ...

    @property
    def ColorSpace(self) -> PsColorSpaceType:
        """
        Read-write. The colorspace for the image.
        """
        ...

    @property
    def Contrast(self) -> int:
        """
        Read-write. The contrast of the shot (-50 - 100).
        """
        ...

    @property
    def Exposure(self) -> float:
        """
        Read-write. The exposure of the shot (4.0 - 4.0).
        """
        ...

    @property
    def GreenHue(self) -> int:
        """
        Read-write. The green hue of the shot (-100 - 100).
        """
        ...

    @property
    def GreenSaturation(self) -> int:
        """
        Read-write. The green saturation of the shot (-100 - 100).
        """
        ...

    @property
    def LuminanceSmoothing(self) -> int:
        """
        Read-write. The luminance smoothing of the shot (0 - 100).
        """
        ...

    @property
    def RedHue(self) -> int:
        """
        Read-write. The red hue of the shot (-100 - 100).
        """
        ...

    @property
    def RedSaturation(self) -> int:
        """
        Read-write. The red saturation of the shot (-100 - 100).
        """
        ...

    @property
    def Resolution(self) -> float:
        """
        Read-write. The resolution of the document in pixels per inch (1 - 999).
        """
        ...

    @property
    def Saturation(self) -> int:
        """
        Read-write. The saturation of the shot (-100 - 100).
        """
        ...

    @property
    def Settings(self) -> PsCameraRAWSettingsType:
        """
        Read-write. The global settings for all Camera RAW options. Default: 0 (psCameraDefault).
        """
        ...

    @property
    def Shadows(self) -> int:
        """
        Read-write. The shadows of the shot (0 - 100).
        """
        ...

    @property
    def ShadowTint(self) -> int:
        """
        Read-write. The shadow tint of the shot (-100 - 100).
        """
        ...

    @property
    def Sharpness(self) -> int:
        """
        Read-write. The sharpness of the shot (0 - 100).
        """
        ...

    @property
    def Size(self) -> PsCameraRAWSize:
        """
        Read-write. The size of the new document.
        """
        ...

    @property
    def Temperature(self) -> int:
        """
        Read-write. The temperature of the shot (2000 - 50000).
        """
        ...

    @property
    def Tint(self) -> int:
        """
        Read-write. The tint of the shot (-150 - 150).
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced CameraRAWOpenOptions object.
        """
        ...

    @property
    def VignettingAmount(self) -> int:
        """
        Read-write. The vignetting amount of the shot (-100 - 100).
        """
        ...

    @property
    def VignettingMidpoint(self) -> int:
        """
        Read-write. The vignetting mid point of the shot (-100 - 100).
        """
        ...

    @property
    def WhiteBalance(self) -> PsWhiteBalanceType:
        """
        Read-write. The white balance options for the image.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .document import Document

class Documents():
    """
    The collection of open Document objects. Note: See ‘Document ’ on page 60 for information on the Document object. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def Count(self) -> int:
        """
        Read-only. The number of elements in the Documents collection.
        """
        ...

    @property
    def Parent(self) -> Application:
        """
        Read-only. The Documents objects’ container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced Documents object.
        """
        ...

    def Add(self, Width, Height, Resolution, Name, Mode, InitialFill, PixelAspectRatio, BitsPerChannel, ColorProfileName) -> Document:
        """
        Adds a Document Object. PixelAspectRatio: range from 0.100 - 10.00. Default 1.0 for a square aspect ratio. BitsPerChannelType has a default value of 8 (psDocument8Bits).
        """
        ...

    def Index(self, ItemPtr:Document) -> int:
        """
        Gets the index of the Document into the collection.
        """
        ...

    def Item(self, ItemKey:int) -> Document:
        """
        Gets an element from the Documents collection.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application

class DICOMOpenOptions():
    """
    Options that can be specified when opening a DICOM format document. Note:DICOMOpenOptions is available in the Extended Version only.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Anonymize(self) -> bool:
        """
        Read-write. Indicates whether to make the patient information anonymous.
        """
        ...

    @property
    def Columns(self) -> int:
        """
        Read-write. Number of columns in n-up configuration.
        """
        ...

    @property
    def Reverse(self) -> bool:
        """
        Read-write. Indicates whether to reverse (invert) the image.
        """
        ...

    @property
    def Rows(self) -> int:
        """
        Read-write. The number of rows in n-up configuration.
        """
        ...

    @property
    def ShowOverlays(self) -> bool:
        """
        Read-write. Indicates whether to show overlays.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced DICOMOpenOptions object.
        """
        ...

    @property
    def WindowLevel(self) -> int:
        """
        Read-write. The contrast of the image in Houndsfield units.
        """
        ...

    @property
    def WindowWidth(self) -> int:
        """
        Read-write. The brightness of the image in Houndsfield units.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .psshapeoperation import PsShapeOperation
    from .application import Application
    from .pathpoints import PathPoints
    from .pathitem import PathItem

class SubPathItem():
    """
    Information about a path. Note: You do not use the SubPathItem object to create a path. Rather, you create path segments using the SubPathInfo object. Use the SubPathItem object to retrieve information about a path. (Note that all of the SubPathItem object’s properties are Read-only.)
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Closed(self) -> bool:
        """
        Read-only. Indicates whether the path is closed.
        """
        ...

    @property
    def Operation(self) -> PsShapeOperation:
        """
        Read-only. The sub path operation on other sub paths.
        """
        ...

    @property
    def Parent(self) -> PathItem:
        """
        Read-only. The object's container.
        """
        ...

    @property
    def PathPoints(self) -> PathPoints:
        """
        Read-only. The PathPoints collection.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced SubPathItem object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .layerset import LayerSet
    from .application import Application
    from .document import Document

class LayerSets():
    """
    The collection of LayerSet objects in the document. Note: See “LayerSet ” on page 99 for information on LayerSet objects.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def Count(self) -> int:
        """
        Read-only. The number of elements in the LayerSets collection.
        """
        ...

    @property
    def Parent(self) -> Document|LayerSet:
        """
        Read-only. The LayerSets object's container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced LayerSets object.
        """
        ...

    def Add(self) -> LayerSet:
        """
        Creates a new LayerSet object.
        """
        ...

    def Index(self, ItemPtr:LayerSet) -> int:
        """
        Gets the index of the LayerSet into the collection.
        """
        ...

    def Item(self, ItemKey:int) -> LayerSet:
        """
        Gets an element from the LayerSets collection.
        """
        ...

    def RemoveAll(self) -> None:
        """
        Removes the layer set, and any layers or layer sets it contains, from the document.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application
    from .psreferenceformtype import PsReferenceFormType

class ActionReference():
    """
    A reference object that contains the data describing the object you are referring to. Note: The actionReference object is part of the Action Manager functionality. See the Photoshop Scripting Guide.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced Action object.
        """
        ...

    def GetContainer(self):
        """
        Gets a reference contained in this reference. Container references provide additional pieces to the reference. This looks like another reference, but it is actually part of the same reference.
        """
        ...

    def GetDesiredClass(self) -> int:
        """
        Gets a number representing the class of the object.
        """
        ...

    def GetEnumeratedType(self) -> int:
        """
        Gets the enumeration type.
        """
        ...

    def GetEnumeratedValue(self) -> int:
        """
        Gets the enumeration value.
        """
        ...

    def GetForm(self) -> PsReferenceFormType:
        """
        Gets the form of an ActionReference.
        """
        ...

    def GetIdentifier(self) -> int:
        """
        Gets the identifier value for a reference whose form is identifier.
        """
        ...

    def GetIndex(self) -> int:
        """
        Gets the index value for a reference in a list or array.
        """
        ...

    def GetName(self) -> str:
        """
        Gets the name of a reference.
        """
        ...

    def GetOffset(self) -> int:
        """
        Gets the offset of the object’s index value.
        """
        ...

    def GetProperty(self) -> int:
        """
        Gets the property ID value.
        """
        ...

    def PutClass(self, DesiredClass:int) -> None:
        """
        Puts a new class form and class type into the reference.
        """
        ...

    def PutEnumerated(self, DesiredClass:int, EnumType:int, Value:int) -> None:
        """
        Puts an enumeration type and ID into a reference along with the desired class for the reference.
        """
        ...

    def PutIdentifier(self, DesiredClass:int, Value:int) -> None:
        """
        Puts a new identifier and value into the reference..
        """
        ...

    def PutIndex(self, DesiredClass:int, Value:int) -> None:
        """
        Puts a new index and value into the reference.
        """
        ...

    def PutName(self, DesiredClass:int, Value:str) -> None:
        """
        Puts a new name and value into the reference.
        """
        ...

    def PutOffset(self, DesiredClass:int, Value:int) -> None:
        """
        Puts a new offset and value into the reference.
        """
        ...

    def PutProperty(self, DesiredClass:int, Value:int) -> None:
        """
        Puts a new property and value into the reference.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .psopendocumentmode import PsOpenDocumentMode
    from .application import Application

class EPSOpenOptions():
    """
    Options that can be specified when opening an EPS format document. 
    """
    @property
    def AntiAlias(self) -> bool:
        """
        Read-write. Indicates whether to use antialias.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def ConstrainProportions(self) -> bool:
        """
        Read-write. Indicates whether to constrain the proportions of the image.
        """
        ...

    @property
    def Height(self) -> float:
        """
        Read-write. The height of the image (unit value).
        """
        ...

    @property
    def Mode(self) -> PsOpenDocumentMode:
        """
        Read-write. The color profile to use as the document mode.
        """
        ...

    @property
    def Resolution(self) -> float:
        """
        Read-write. The resolution of the document in pixels per inch.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced EPSOpenOptions object.
        """
        ...

    @property
    def Width(self) -> float:
        """
        Read-write. The width of the image (unit value).
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .rgbcolor import RGBColor
    from .application import Application
    from .psgallerysecuritytextrotatetype import PsGallerySecurityTextRotateType
    from .psgallerysecuritytextpositiontype import PsGallerySecurityTextPositionType
    from .psgallerysecuritytype import PsGallerySecurityType
    from .psgalleryfonttype import PsGalleryFontType

class GallerySecurityOptions():
    """
    Options that define the SecurityOptions property of the GalleryOptions object. See ‘GalleryOptions ’ on page 82.Tip: You can preserve default values for many GallerySecurityOptions properties by setting the GalleryOptions property PreserveAllMetadata to true or by choosing File > Automate > Web Photo Gallery , and then choosing Preserve all metadata on the Options area of the Web Photo Gallery dialog. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the collection belongs to.
        """
        ...

    @property
    def Content(self) -> PsGallerySecurityType:
        """
        Read-write. The Web photo gallery security content. Default: 1.
        """
        ...

    @property
    def Font(self) -> PsGalleryFontType:
        """
        Read-write. The Web photo gallery security font. Default: 1.
        """
        ...

    @property
    def FontSize(self) -> int:
        """
        Read-write. The Web photo gallery security font size (1 - 72; default: 3).
        """
        ...

    @property
    def Opacity(self) -> int:
        """
        Read-write. The Web page security opacity as a percent. Default: 100.
        """
        ...

    @property
    def Text(self) -> str:
        """
        Read-write. The Web photo gallery security custom text.
        """
        ...

    @property
    def TextColor(self) -> RGBColor:
        """
        Read-write. The Web page security text color.
        """
        ...

    @property
    def TextPosition(self) -> PsGallerySecurityTextPositionType:
        """
        Read-write. The Web photo gallery security text position. Default: 1.
        """
        ...

    @property
    def TextRotate(self) -> PsGallerySecurityTextRotateType:
        """
        Read-write. The Web photo gallery security text orientation to use. Default: 1.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced GallerySecurityOptions object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .document import Document

class CountItem():
    """
    A counted item in the document. Also see the method AutoCount , defined on Document.Note:CountItem is available in the Extended Version only.For additional information about count items, see Adobe Photoshop help on the Count Tool.
    """
    @property
    def Position(self) -> List[float]:
        """
        Read-only. The position of the count item in the document. The array (x,y) represents the horizontal and vertical location of the count item.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The CountItem object’s container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced CountItem object.
        """
        ...

    def Delete(self) -> None:
        """
        Deletes the CountItem object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .document import Document
    from .preferences import Preferences
    from .batchoptions import BatchOptions
    from .application import Application
    from .documents import Documents
    from .psjavascriptexecutionmode import PsJavaScriptExecutionMode
    from .notifiers import Notifiers
    from .textfonts import TextFonts
    from .actiondescriptor import ActionDescriptor
    from .contactsheetoptions import ContactSheetOptions
    from .solidcolor import SolidColor
    from .picturepackageoptions import PicturePackageOptions
    from .pspurgetarget import PsPurgeTarget
    from .actionreference import ActionReference
    from .measurementlog import MeasurementLog
    from .psdialogmodes import PsDialogModes

class Application():
    """
    The Adobe Adobe Photoshop application object. The Application object contains all other Adobe Photoshop objects.
    """
    @property
    def ActiveDocument(self) -> Document:
        """
        Read-write. The frontmost document. (Setting this property is equivalent to clicking an open document in the Adobe Photoshop application to bring it to the front of the screen.)
        """
        ...

    @property
    def Application(self):
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def BackgroundColor(self) -> SolidColor:
        """
        Read-write. The color mode for the document’s background color.
        """
        ...

    @property
    def Build(self) -> str:
        """
        Read-only. The build number of the application.
        """
        ...

    @property
    def ColorSettings(self) -> str:
        """
        Read-write. The name of selected color setting’s set.
        """
        ...

    @property
    def CurrentTool(self) -> str:
        """
        Read-write. The name of the current tool selected.
        """
        ...

    @property
    def DisplayDialogs(self) -> PsDialogModes:
        """
        Read-write. The dialog mode for the document, which indicates whether or not Adobe Photoshop displays dialogs when the script runs.
        """
        ...

    @property
    def Documents(self) -> Documents:
        """
        Read-only. The collection of open documents.
        """
        ...

    @property
    def Fonts(self) -> TextFonts:
        """
        Read-only. The fonts installed on this system.
        """
        ...

    @property
    def ForegroundColor(self) -> SolidColor:
        """
        Read-write. The default foreground color (used to paint, fill, and stroke selections).
        """
        ...

    @property
    def FreeMemory(self) -> float:
        """
        Read-only. The amount of unused memory available to Adobe Photoshop.
        """
        ...

    @property
    def Locale(self) -> str:
        """
        Read-only. The language location of the application.
        """
        ...

    @property
    def MacintoshFileTypes(self) -> List[str]:
        """
        Read-only. A list of file image types Adobe Photoshop can open.
        """
        ...

    @property
    def MeasurementLog(self) -> MeasurementLog:
        """
        Read-only. The log of measurements taken.
        """
        ...

    @property
    def Name(self) -> str:
        """
        Read-only. The application's name.
        """
        ...

    @property
    def Notifiers(self) -> Notifiers:
        """
        Read-only. The collection of notifiers currently configured (in the Scripts Events Manager menu in the Adobe Photoshop application).
        """
        ...

    @property
    def NotifiersEnabled(self) -> bool:
        """
        Read-write. Indicates whether all notifiers are enabled or disabled.
        """
        ...

    @property
    def Path(self) -> str:
        """
        Read-only. The full path (as a String) to the location of the Adobe Photoshop application.
        """
        ...

    @property
    def Preferences(self) -> Preferences:
        """
        Read-only. The application preference settings (equivalent to selecting Edit > Preferences in the Adobe Photoshop application in Windows® or Photoshop > Preferences in Mac OS®).
        """
        ...

    @property
    def PreferencesFolder(self) -> str:
        """
        Read-only. The full path to the Preferences folder.
        """
        ...

    @property
    def RecentFiles(self) -> List[str]:
        """
        Read-only. Files (as an Array of String) in the Recent Files list.
        """
        ...

    @property
    def ScriptingBuildDate(self) -> str:
        """
        Read-only. The build date of the Scripting interface.
        """
        ...

    @property
    def ScriptingVersion(self) -> str:
        """
        Read-only. The version of the Scripting interface.
        """
        ...

    @property
    def SystemInformation(self) -> str:
        """
        Read-only. The system information for the applicaiton and the system.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced Application object.
        """
        ...

    @property
    def Version(self) -> str:
        """
        Read-only. The version of Adobe Photoshop application you are running.
        """
        ...

    @property
    def Visible(self) -> bool:
        """
        Read-write. Indicates whether the Adobe Photoshop application is the front-most/active application.
        """
        ...

    @property
    def WinColorSettings(self) -> str:
        """
        Read-only. Color settings.
        """
        ...

    @property
    def WindowsFileTypes(self) -> List[str]:
        """
        Read-only. A list of file image extensions Adobe Photoshop can open.
        """
        ...

    def Batch(self, InputFiles:List[str], Action:str, From:str, Options:BatchOptions) -> str:
        """
        Runs the batch automation routine (similar to the Batch command, or File > Automate > Batch in the Adobe Photoshop application). Note:The inputFiles parameter specifies the source for the files (as an array of String) to be manipulated by the Batch command.
        """
        ...

    def ChangeColorSettings(self, Name:str, File:str) -> None:
        """
        Sets Color Settings to a named set or to the contents of a settings file. The File parameter represents the path to the file as a String.
        """
        ...

    def CharIDToTypeID(self, CharID:str) -> int:
        """
        Converts from a four character code (character ID) to a runtime ID.
        """
        ...

    def DoAction(self, Action:str, From:str) -> None:
        """
        Plays an action from the Actions palette.
        """
        ...

    def DoJavaScript(self, JavaScriptCode:str, Arguments:list, ExecutionMode:PsJavaScriptExecutionMode) -> str:
        """
        Executes the specified JavaScript code.
        """
        ...

    def DoJavaScriptFile(self, JavaScriptFile:str, Arguments:list, ExecutionMode:PsJavaScriptExecutionMode) -> str:
        """
        Executes the specified JavaScript code, from the file specified by argument JavaScriptFile.
        """
        ...

    def ExecuteAction(self, EventID:int, Descriptor:ActionDescriptor, DisplayDialogs:PsDialogModes) -> ActionDescriptor:
        """
        Plays an ActionManager event.
        """
        ...

    def ExecuteActionGet(self, Reference:ActionReference) -> ActionDescriptor:
        """
        Obtains an ActionDescriptor.
        """
        ...

    def FeatureEnabled(self, Name:str) -> bool:
        """
        Determines whether the feature specified by Name is enabled. The following features are supported as values for Name: “photoshop/extend ed” “photoshop/standa rd” “photoshop/trial”
        """
        ...

    def Load(self, Document:str) -> None:
        """
        Loads a support document from the specified file path location.
        """
        ...

    def MakeContactSheet(self, InputFiles:List[str], Options:ContactSheetOptions) -> str:
        """
        Deprecated for Adobe Photoshop. Creates a contact sheet from the specified files.
        """
        ...

    def MakePDFPresentation(self, InputFilesOutputFiles, Options) -> str:
        """
        Deprecated for Adobe Photoshop. Creates a PDF presentation file from the specified input files. Note:The return string contains the path to the PDF file.
        """
        ...

    def MakePhotoGallery(self, InputFolderOutputFolder, Options) -> str:
        """
        Deprecated for Adobe Photoshop. Creates a Web photo gallery from the files in the specified input folder.
        """
        ...

    def MakePhotomerge(self, InputFiles:List[str]) -> str:
        """
        Deprecated for Adobe Photoshop. Merges multiple files into one; user interaction required.
        """
        ...

    def MakePicturePackage(self, InputFiles:List[str], Options:PicturePackageOptions) -> str:
        """
        Deprecated for Adobe Photoshop. Creates a picture package from the specified input files.
        """
        ...

    def Open(self, Document:str, As:Any, AsSmartObject:bool) -> Document:
        """
        Opens the specified document as the optionally specified file type. Optional paramater AsSmartObject (default:false) indicates whether to create a smart object around the opened document.
        """
        ...

    def OpenDialog(self) -> List[str]:
        """
        Uses the Photoshop open dialog box to select files. Returns an Array of String representing the files selected.
        """
        ...

    def Purge(self, Target:PsPurgeTarget) -> None:
        """
        Purges one or more caches.
        """
        ...

    def Quit(self) -> None:
        """
        Quits the Photoshop application.
        """
        ...

    def Refresh(self) -> None:
        """
        Pauses the script while the application refreshes.
        """
        ...

    def StringIDToTypeID(self, StringID:str) -> int:
        """
        Converts from a String ID to a runtime ID.
        """
        ...

    def TypeIDToCharID(self, TypeID:int) -> str:
        """
        Converts from a runtime ID to a character ID.
        """
        ...

    def TypeIDToStringID(self, TypeID:int) -> str:
        """
        Converts from a runtime ID to a String ID.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .document import Document
    from .psselectiontype import PsSelectionType
    from .application import Application
    from .channel import Channel
    from .pscolorblendmode import PsColorBlendMode
    from .psanchorposition import PsAnchorPosition
    from .psstrokelocation import PsStrokeLocation
    from .solidcolor import SolidColor
    from .historystate import HistoryState

class Selection():
    """
    The selected area of a document or layer. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Bounds(self) -> List[float]:
        """
        Read-only. The bounding rectangle of the entire selection.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The object's container.
        """
        ...

    @property
    def Solid(self) -> bool:
        """
        Read-only. Indicates if the bounding rectangle is a solid.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced Selection object.
        """
        ...

    def Clear(self) -> None:
        """
        Clears the selection and does not copy it to the clipboard.
        """
        ...

    def Contract(self, By:float) -> None:
        """
        Contracts the selection by the specified amount.
        """
        ...

    def Copy(self, Merge:bool) -> None:
        """
        Copies the selection to the clipboard. When the optional argument is used and set to true, a merged copy is performed (all visible layers in the selection are copied).
        """
        ...

    def Cut(self) -> None:
        """
        Clears the current selection and copies it to the clipboard.
        """
        ...

    def Deselect(self) -> None:
        """
        Deselects the current selection.
        """
        ...

    def Expand(self, By:float) -> None:
        """
        Expands the selection by the specified amount.
        """
        ...

    def Feather(self, By:float) -> None:
        """
        Feathers the edges of the selection by the specified amount.
        """
        ...

    def Fill(self, Filltype:List[SolidColor|HistoryState], Mode:PsColorBlendMode, Opacity:int, PreserveTransparency:bool) -> None:
        """
        Fills the selection (Opacity: 1 - 100 as percent).
        """
        ...

    def Grow(self, Tolerance:int, AntiAlias:bool) -> None:
        """
        Grows the selection to include all adjacent pixels falling within the specified tolerance range.
        """
        ...

    def Invert(self) -> None:
        """
        Inverts the selection (deselects the selection and selects the rest of the layer or document). Note:To flip the selection shape, see Rotate.
        """
        ...

    def Load(self, From, Combination, Inverting) -> None:
        """
        Loads the selection from the specified channel.
        """
        ...

    def MakeWorkPath(self, Tolerance:float) -> None:
        """
        Makes this selection item the work path for this document.
        """
        ...

    def Resize(self, Horizontal:float, Vertical:float, Anchor:PsAnchorPosition) -> None:
        """
        Resizes the selected area to the specified dimensions and anchor position.
        """
        ...

    def ResizeBoundary(self, Horizontal:float, Vertical:float, Anchor:PsAnchorPosition) -> None:
        """
        Changes the size of the selection to the specified dimensions around the specified anchor.
        """
        ...

    def Rotate(self, Angle:float, Anchor:PsAnchorPosition) -> None:
        """
        Rotates the selection by the specified amount around the specified anchor point.
        """
        ...

    def RotateBoundary(self, Angle:float, Anchor:PsAnchorPosition) -> None:
        """
        Rotates the boundary of the selection around the specified anchor.
        """
        ...

    def Select(self, Region, Type, Feather, AntiAlias) -> None:
        """
        Selects the specified region.
        """
        ...

    def SelectAll(self) -> None:
        """
        Selects the entire layer.
        """
        ...

    def SelectBorder(self, Width:float) -> None:
        """
        Selects the selection border only (in the specified width); subsequent actions do not affect the selected area within the borders.
        """
        ...

    def Similar(self, Tolerance:int, AntiAlias:bool) -> None:
        """
        Grows the selection to include pixels throughout the image falling within the tolerance range.
        """
        ...

    def Smooth(self, Radius:int) -> None:
        """
        Cleans up stray pixels left inside or outside a color-based selection (within the radius specified in pixels).
        """
        ...

    def Store(self, Into:Channel, Combination:PsSelectionType) -> None:
        """
        Saves the selection as a channel.
        """
        ...

    def Stroke(self, StrokeColor:SolidColor, Width:int, Location:PsStrokeLocation, Mode:PsColorBlendMode, Opacity:int, PreserveTransparency:bool) -> None:
        """
        Strokes the selection border (Opacity: 1 - 100 as percent).
        """
        ...

    def Translate(self, DeltaX:float, DeltaY:float) -> None:
        """
        Moves the entire selection relative to its current position.
        """
        ...

    def TranslateBoundary(self, DeltaX:float, DeltaY:float) -> None:
        """
        Moves the selection relative to its current position.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .solidcolor import SolidColor
    from .pschanneltype import PsChannelType
    from .application import Application
    from .document import Document

class Channel():
    """
    Object that stores information about a color element in the image, analogous to a plate in the printing process that applies a single color. The document ’s color mode determines the number of default channels; for example, an RGB docu ment has four default channels: ?A composite channel: RGB?Three component channels: red, green, blueA channel can also be an al pha channel, which stores se lections as masks, or a sp ot channel, which stores spot colors.
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Color(self) -> SolidColor:
        """
        Read-write. The color of the channel. Note:Not valid when Type = 1.
        """
        ...

    @property
    def Histogram(self) -> List[int]:
        """
        Read-only. A histogram of the color of the channel. Note:Not valid when Type = 1. For component channel histogram values, use the Histogram property of the Document object instead. See Histogram.
        """
        ...

    @property
    def Kind(self) -> PsChannelType:
        """
        Read-write. The channel type.
        """
        ...

    @property
    def Name(self) -> str:
        """
        Read-write. The channel's name.
        """
        ...

    @property
    def Opacity(self) -> float:
        """
        Read-write. The opacity to use for alpha channels or the solidity to use for spot channels (0 - 100). Note:Valid only when Type = 2 or Type = 3.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The object's container.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced Channel object.
        """
        ...

    @property
    def Visible(self) -> bool:
        """
        Read-write. Indicates whether the channel is visible.
        """
        ...

    def Delete(self) -> None:
        """
        Deletes the channel.
        """
        ...

    def Duplicate(self, TargetDocument:Document):
        """
        Duplicates the channel.
        """
        ...

    def Merge(self) -> None:
        """
        Merges a spot channel into the component channels.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .document import Document
    from .pspathkind import PsPathKind
    from .psselectiontype import PsSelectionType
    from .application import Application
    from .subpathitems import SubPathItems

class PathItem():
    """
    A path or drawing object, such as the outline of a sh ape or a straight or curved line, which contains sub paths that comprise its geometry. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Kind(self) -> PsPathKind:
        """
        Read-write. The PathItem object’s type.
        """
        ...

    @property
    def Name(self) -> str:
        """
        Read-write. The PathItem object’s name.
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The PathItem object's container.
        """
        ...

    @property
    def SubPathItems(self) -> SubPathItems:
        """
        Read-only. The sub path objects for this PathItem object.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced PathItem object.
        """
        ...

    def Delete(self) -> None:
        """
        Deletes this PathItem object.
        """
        ...

    def Deselect(self) -> None:
        """
        Deselects this PathItem object.
        """
        ...

    def Duplicate(self, Name:str) -> None:
        """
        Duplicates this PathItem object with the new name specified in the argument.
        """
        ...

    def FillPath(self, FillColor, Mode, Opacity, PreserveTransparency, Feather, WholePath, AntiAlias) -> None:
        """
        Fills the area enclosed by the path (Opacity: 0 - 100 as percent; Feather: 0.0 - 250.0 in pixels).
        """
        ...

    def MakeClippingPath(self, Flatness:float) -> None:
        """
        Makes this PathItem object the clipping path for this document; the optional parameter tells the PostScript printer how to approximate curves in the path (0.2 - 100).
        """
        ...

    def MakeSelection(self, Feather:float, AntiAlias:bool, Operation:PsSelectionType) -> None:
        """
        Makes a Selection object, whose border is the path, from this PathItem Object (Feather: 0.0 - 250.0 in pixels). Note:See ‘Selection’ on page 136.
        """
        ...

    def Select(self) -> None:
        """
        Makes this PathItem object the active or selected PathItem object.
        """
        ...

    def StrokePath(self, Tool, SimulatePressure) -> None:
        """
        Strokes the path with the specified information.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .application import Application

class PNGSaveOptions():
    """
    Options that can be specified when saving a document in PNG format. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Compression(self) -> int:
        """
        Read-write. The compression of the image (0 - 9), Default: 0.
        """
        ...

    @property
    def Interlaced(self) -> bool:
        """
        Read-write. Indicates whether the should rows be interlaced. Default: false.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced PNGSaveOptions object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .pspointkind import PsPointKind
    from .application import Application

class PathPointInfo():
    """
    A point on a path, expressed as an array of three coordi nate arrays: the anchor point, left direction point, and right direction point. For paths that are straight segments (not curved), the coordinates of all three points are the same. For curved segments, the coordinates are different. The difference between the anchor point and the left or right direction points determines the arc of the curve. You use the left direction point to bend the curve “outward” or make it convex; you use the right direction point to bend the curve “inward” or make it concave.
    """
    @property
    def Anchor(self) -> list:
        """
        Read-write. The x and y coordinates of one end point of the path segment.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def Kind(self) -> PsPointKind:
        """
        Read-write. The PathPointInfo object’s kind.
        """
        ...

    @property
    def LeftDirection(self) -> List[float]:
        """
        Read-write. The location of the left direction point (’in’ position).
        """
        ...

    @property
    def RightDirection(self) -> List[float]:
        """
        Read-write. The location of the right handle (’out’ position).
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced PathPointInfo object.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .psbyteorder import PsByteOrder
    from .application import Application

class RawFormatOpenOptions():
    """
    Options that can be specified when opening a document in RAW format. 
    """
    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def BitsPerChannel(self) -> int:
        """
        Read-write. The number of bits for each channel. Note:The only valid values are BitsPerChannel = 8 or BitsPerChannel = 16.
        """
        ...

    @property
    def ByteOrder(self) -> PsByteOrder:
        """
        Read-write. The order in which bytes will be read. Note:Valid only when BitsPerChannel = 16. See BitsPerChannel.
        """
        ...

    @property
    def ChannelNumber(self) -> int:
        """
        Read-write. The number of channels in the image (1 - 56). Note:The value of ChannelNumber cannot exceed the number of channels in the image. When BitsPerChannel = 16, only the following values are valid: 1, 3, or 4. See BitsPerChannel.
        """
        ...

    @property
    def HeaderSize(self) -> int:
        """
        Read-write. The number of bytes of information that will appear in the file before actual image information begins; that is, the number of zeroes inserted at the beginning of the file as placeholders (0 - 1919999).
        """
        ...

    @property
    def Height(self) -> int:
        """
        Read-write. The height of the image (in pixels).
        """
        ...

    @property
    def InterleaveChannels(self) -> bool:
        """
        Read-write. Indicates whether to store color values sequentially.
        """
        ...

    @property
    def RetainHeader(self) -> bool:
        """
        Read-write. Indicates whether to retain the header when saving. Note:Valid only when HeaderSize is 1 or greater.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced RawFormatOpenOptions object.
        """
        ...

    @property
    def Width(self) -> int:
        """
        Read-write. The image width in pixels.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .psrasterizetype import PsRasterizeType
    from .xmpmetadata import XMPMetadata
    from .pslenstype import PsLensType
    from .psblendmode import PsBlendMode
    from .application import Application
    from .textitem import TextItem
    from .psripplesize import PsRippleSize
    from .pscreatefields import PsCreateFields
    from .pssmartblurquality import PsSmartBlurQuality
    from .pseliminatefields import PsEliminateFields
    from .psanchorposition import PsAnchorPosition
    from .pslayerkind import PsLayerKind
    from .pselementplacement import PsElementPlacement
    from .psadjustmentreference import PsAdjustmentReference
    from .document import Document
    from .psspherizemode import PsSpherizeMode
    from .pszigzagtype import PsZigZagType
    from .layerset import LayerSet
    from .pspolarconversiontype import PsPolarConversionType
    from .artlayer import ArtLayer
    from .psoffsetundefinedareas import PsOffsetUndefinedAreas
    from .pssmartblurmode import PsSmartBlurMode

class ArtLayer():
    """
    An object within a document that contains the visual elements of the image (equivalent to a layer in the Adobe Photoshop application).
    """
    @property
    def AllLocked(self) -> bool:
        """
        Read-write. Indicates whether to completely lock the layer’s contents and settings.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that this art layer belongs to.
        """
        ...

    @property
    def BlendMode(self) -> PsBlendMode:
        """
        Read-write. The layer’s blending mode.
        """
        ...

    @property
    def Bounds(self) -> list:
        """
        Read-only. An array of coordinates that describes the bounding rectangle of the ArtLayer.
        """
        ...

    @property
    def BoundsNoEffects(self) -> list:
        """
        Read-only. An array of coordinates that describes the bounding rectangle of the ArtLayer not including effects.
        """
        ...

    @property
    def FillOpacity(self) -> float:
        """
        Read-write. The interior opacity of the layer (0.0 - 100.0).
        """
        ...

    @property
    def Grouped(self) -> bool:
        """
        Read-write. Indicates whether to group this layer with the layer beneath it.
        """
        ...

    @property
    def IsBackgroundLayer(self) -> bool:
        """
        Read-write. Indicates whether the layer is a background layer or normal layer. Note:A document can have only one background layer.
        """
        ...

    @property
    def Kind(self) -> PsLayerKind:
        """
        Read-write. Sets the layer’s kind (such as 'text layer') for an empty layer. Note:Valid only when the layer is empty and when IsBackgroundLayer is false. See IsBackgroundLayer. Note:You can use the kind property to make a background layer a normal layer; however, to make a layer a background layer, you must set IsBackgroundLayer to true.
        """
        ...

    @property
    def LinkedLayers(self) -> List[ArtLayer|LayerSet]:
        """
        Read-only. The layers linked to this layer. Note:See Link.
        """
        ...

    @property
    def Name(self) -> str:
        """
        Read-write. The layer’s name.
        """
        ...

    @property
    def Opacity(self) -> float:
        """
        Read-write. The master opacity of the layer (0.0 - 100.0).
        """
        ...

    @property
    def Parent(self) -> Document:
        """
        Read-only. The object's container.
        """
        ...

    @property
    def PixelsLocked(self) -> bool:
        """
        Read-write. Indicates whether the pixels in the layer’s image can be edited using the paintbrush tool.
        """
        ...

    @property
    def PositionLocked(self) -> bool:
        """
        Read-write. Indicates whether the pixels in the layer’s image can be moved within the layer.
        """
        ...

    @property
    def TextItem(self) -> TextItem:
        """
        Read-only. The text item that is associated with the layer. Note:Valid only when Kind = 2. See Kind.
        """
        ...

    @property
    def TransparentPixelsLocked(self) -> bool:
        """
        Read-write. Indicates whether editing is confined to the opaque portions of the layer.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced ArtLayer object.
        """
        ...

    @property
    def Visible(self) -> bool:
        """
        Read-write. Indicates whether the layer is visible.
        """
        ...

    @property
    def XMPMetadata(self) -> XMPMetadata:
        """
        Read-only. XMP data for the layer.
        """
        ...

    def AdjustBrightnessContrast(self, Brightness:int, Contrast:int) -> None:
        """
        Adjusts the brightness (-100 - 100) and contrast (-100 - 100).
        """
        ...

    def AdjustColorBalance(self, Shadows, Midtones, Highlights, PreserveLuminosity) -> None:
        """
        Adjusts the color balance of the layer’s component channels. For Shadows, Midtones, and Highlights, the array must include three values (-100 - 100), which represent cyan or red, magenta or green, and yellow or blue, when the document mode is CMYK or RGB. Note:See mode in the Properties table of the Document object.
        """
        ...

    def AdjustCurves(self, CurveShape) -> None:
        """
        Adjusts the tonal range of the selected channel using up to fourteen points.
        """
        ...

    def AdjustLevels(self, InputRangeStart:int, InputRangeEnd:int, InputRangeGamma:float, OutputRangeStart:int, OutputRangeEnd:int) -> None:
        """
        Adjusts the levels of the selected channels (InputRangeStart: 0 - 253; InputRangeEnd: (InputRangeStart + 2) - 255; InputRangeGamma: 0.10 - 9.99; OutputRangeStart: 0 - 253; OutputRangeEnd: (OutputRangeStart + 2) - 255.
        """
        ...

    def ApplyAddNoise(self, Amount, Distribution, Monochromatic) -> None:
        """
        Applies the Add Noise filter (Amount: 0.1 - 400, as a percentage).
        """
        ...

    def ApplyAverage(self) -> None:
        """
        Applies the Average filter.
        """
        ...

    def ApplyBlur(self) -> None:
        """
        Applies the Blur filter.
        """
        ...

    def ApplyBlurMore(self) -> None:
        """
        Applies the Blur More filter.
        """
        ...

    def ApplyClouds(self) -> None:
        """
        Applies the Clouds filter.
        """
        ...

    def ApplyCustomFilter(self, Characteristics:List[int], Scale:int, Offset:int) -> None:
        """
        Applies a custom filter. Note:Required parameter values define the filter. Refer to Adobe Photoshop Help for specific instructions.
        """
        ...

    def ApplyDeInterlace(self, EliminateFields:PsEliminateFields, CreateFields:PsCreateFields) -> None:
        """
        Applies the De-Interlace filter.
        """
        ...

    def ApplyDespeckle(self) -> None:
        """
        Applies the Despeckle filter.
        """
        ...

    def ApplyDifferenceClouds(self) -> None:
        """
        Applies the Difference Clouds filter.
        """
        ...

    def ApplyDiffuseGlow(self, Graininess:int, GlowAmount:int, ClearAmount:int) -> None:
        """
        Applies the Diffuse Glow filter (Graininess: 0 - 10; GlowAmount: 0 - 20; ClearAmount: 0 - 20).
        """
        ...

    def ApplyDisplace(self, HorizontalScale, VerticalScale, DisplacementType, UndefinedAreas, DisplacementMapFiles) -> None:
        """
        Applies the Displace filter using the specified horizontal and vertical scale (-999 - 999), mapping type, treatment of undistorted areas, and path to the distortion image map.
        """
        ...

    def ApplyDustAndScratches(self, Radius:int, Threshold:int) -> None:
        """
        Applies the Dust & Scratches filter (Radius: 1 - 100; Threshold: 0 - 255).
        """
        ...

    def ApplyGaussianBlur(self, Radius:float) -> None:
        """
        Applies the Gaussian Blur filter within the specified radius (in pixels) (0.1 - 250.0).
        """
        ...

    def ApplyGlassEffect(self, Distortion, Smoothness, Scaling, Invert, Texture, TextureFile) -> None:
        """
        Applies the Glass filter (Distortion: 0 - 20; Smoothness: 1 - 15; Scaling (in percent): 50 - 200). Note:The TextureFile parameter represents the path to a texture file as a String.
        """
        ...

    def ApplyHighPass(self, Radius:float) -> None:
        """
        Applies the High Pass filter within the specified radius (in pixels) (0.1 - 250.0).
        """
        ...

    def ApplyLensBlur(self, Source, FocalDistance, InvertDepthMap, Shape, Radius, BladeCurvature, Rotation, Brightness, Threshold, Amount, Distribution, Monochromatic) -> None:
        """
        Applies the Lens Blur filter. source: the source for the depth map. Default: 1 (psNoSource). focalDistance : the blur focal distance for the depth map (default: 0). invertDepthMask : whether the depth map is inverted (default: false). shape: The shape of the iris. Default: 2 (psHexagon). radius: The radius of the iris (default: 15). bladeCurvature: The blade curvature of the iris (default: 0). rotation: The rotation of the iris (default: 0) brightness: The brightness for the specular highlights (default: 0). threshold: The threshold for the specular highlights (default: 0). amount: The amount of noise (default: 0) distribution: The distribution value for the noise. Default: 1 (psUniformNoise). monochromatic: Indicates whether the noise is monochromatic (default: false).
        """
        ...

    def ApplyLensFlare(self, Brightness:int, FlareCenter:List[float], LensType:PsLensType) -> None:
        """
        Applies the Lens Flare filter with the specified brightness (0 - 300, as a percentage), the x and y coordinates (unit value) of the flare center, and the lens type.
        """
        ...

    def ApplyMaximum(self, Radius:float) -> None:
        """
        Applies the Maximum filter within the specified radius (in pixels) (1 - 100).
        """
        ...

    def ApplyMedianNoise(self, Radius:float) -> None:
        """
        Applies the Median Noise filter within the specified radius (in pixels) (1 - 100).
        """
        ...

    def ApplyMinimum(self, Radius:float) -> None:
        """
        Applies the Minimum filter within the specified radius (in pixels) (1 - 100).
        """
        ...

    def ApplyMotionBlur(self, Angle:int, Radius:float) -> None:
        """
        Applies the Motion Blur filter (Angle: -360 - 360; Radius: 1 - 999).
        """
        ...

    def ApplyNTSC(self) -> None:
        """
        Applies the NTSC colors filter.
        """
        ...

    def ApplyOceanRipple(self, Size:int, Magnitude:int) -> None:
        """
        Applies the Ocean Ripple filter in the specified size (1 - 15) and magnitude (0 - 20).
        """
        ...

    def ApplyOffset(self, Horizontal:float, Vertical:float, UndefinedAreas:PsOffsetUndefinedAreas) -> None:
        """
        Moves the layer the specified amount horizontally and vertically (min/max amounts depend on layer size), leaving an undefined area at the layer’s original location.
        """
        ...

    def ApplyPinch(self, Amount:int) -> None:
        """
        Applies the Pinch filter in the specified amount (as a percentage) (-100 - 100).
        """
        ...

    def ApplyPolarCoordinates(self, Conversion:PsPolarConversionType) -> None:
        """
        Applies the Polar Coordinates filter.
        """
        ...

    def ApplyRadialBlur(self, Amount, BlurMethod, BlurQuality, BlurCenter) -> None:
        """
        Applies the Radial Blur filter in the specified amount (1 - 100) using either a spin or zoom effect and the specified quality. The parameter BlurCenter is the position (unit value).
        """
        ...

    def ApplyRipple(self, Amount:int, Size:PsRippleSize) -> None:
        """
        Applies the Ripple filter in the specified amount (-999 to 999) throughout the image and in the specified size.
        """
        ...

    def ApplySharpen(self) -> None:
        """
        Applies the Sharpen filter.
        """
        ...

    def ApplySharpenEdges(self) -> None:
        """
        Applies the Sharpen Edges filter.
        """
        ...

    def ApplySharpenMore(self) -> None:
        """
        Applies the Sharpen More filter.
        """
        ...

    def ApplyShear(self, Curve, UndefinedAreas) -> None:
        """
        Applies the Shear filter (curve: 2 - 255 points). Note:You must define at least two points in the Curve parameter.
        """
        ...

    def ApplySmartBlur(self, Radius:float, Threshold:float, BlurQuality:PsSmartBlurQuality, Mode:PsSmartBlurMode) -> None:
        """
        Applies the smart blur filter (Radius: 0.1 - 100.0; Threshold: 0.1 - 100.0).
        """
        ...

    def ApplySpherize(self, Amount:int, Mode:PsSpherizeMode) -> None:
        """
        Applies the Spherize filter in the specified amount (as percentage) (-100 - 100).
        """
        ...

    def ApplyStyle(self, StyleName:str) -> None:
        """
        Applies the specified style to the layer. Note:You must use a style from the Styles list in the Layer Style dialog.
        """
        ...

    def ApplyTextureFill(self, TextureFile:str) -> None:
        """
        Applies the Texture Fill filter.
        """
        ...

    def ApplyTwirl(self, Angle:int) -> None:
        """
        Applies the Twirl filter at the specified angle (-999 - 999).
        """
        ...

    def ApplyUnSharpMask(self, Amount:float, Radius:float, Threshold:int) -> None:
        """
        Applies the Unsharp Mask filter (Amount: 1 - 500 as percent; Radius: 0.1 - 250.00; Threshold: 0 - 255).
        """
        ...

    def ApplyWave(self, GeneratorNumber, MinimumWavelength, MaximumWavelength, MinimumAmplitude, MaximumAmplitude, HorizontalScale, VerticalScale, WaveType, UndefinedAreas, RandomSeed) -> None:
        """
        Applies the Wave filter (GeneratorNumber: 1 - 999; MinimumWavelength: 1 - 998; MaximumWavelength: 2 - MinimumWavelength + 1; MinimumAmplitude: 1 - 998; MaximumAmplitude: 2 - MinimumAmplitude + 1; AmountScale: 1 - 100, as a percentage; VerticalScale: 1 - 100, as a percentage).
        """
        ...

    def ApplyZigZag(self, Amount:int, Ridges:int, Style:PsZigZagType) -> None:
        """
        Applies the Zigzag filter (Amount: -100 - 100; Ridges: 0 - 20).
        """
        ...

    def AutoContrast(self) -> None:
        """
        Adjusts the contrast of the selected channels automatically.
        """
        ...

    def AutoLevels(self) -> None:
        """
        Adjusts the levels of the selected channels using the auto levels option.
        """
        ...

    def Clear(self) -> None:
        """
        Cuts the layer without moving it to the clipboard.
        """
        ...

    def Copy(self, Merge:bool) -> None:
        """
        Copies the layer to the clipboard. When the optional argument is set to true, a merged copy is performed (that is, all visible layers are copied to the clipboard).
        """
        ...

    def Cut(self) -> None:
        """
        Cuts the layer to the clipboard.
        """
        ...

    def Desaturate(self) -> None:
        """
        Converts a color image to a grayscale image in the current color mode by assigning equal values of each component color to each pixel.
        """
        ...

    def Duplicate(self, RelativeObject:ArtLayer|LayerSet, InsertionLocation:PsElementPlacement):
        """
        Creates a duplicate of the object on the screen.
        """
        ...

    def Equalize(self) -> None:
        """
        Redistributes the brightness values of pixels in an image to more evenly represent the entire range of brightness levels within the image.
        """
        ...

    def Invert(self) -> None:
        """
        Inverts the colors in the layer by converting the brightness value of each pixel in the channels to the inverse value on the 256-step color-values scale.
        """
        ...

    def Link(self, With:ArtLayer|LayerSet) -> None:
        """
        Links the layer with the specified layer.
        """
        ...

    def Merge(self):
        """
        Merges the layer down, removing the layer from the document; returns a reference to the art layer that this layer is merged into.
        """
        ...

    def MixChannels(self, OutputChannels, Monochrome) -> None:
        """
        Modifies a targeted (output) color channel using a mix of the existing color channels in the image. (OutputChannels = An array of channel specifications. For each component channel, specify a list of adjustment values (-200 - 200) followed by a 'constant' value (-200 - 200).) Note:When Monochrome = true, the maximum number of channel value specifications is 1. Note:Valid only when Document.Mode = 2 or Document.Mode = 3. Note:RGB arrays must include four doubles. CMYK arrays must include five doubles.
        """
        ...

    def Move(self, ApplicationObject:ArtLayer|LayerSet, InsertionLocation:PsElementPlacement) -> None:
        """
        Moves the layer relative to the object specified in parameters. Note:For art layers, only the constant values 3 and 4 are valid. For layer sets, only the constant values 3 and 0 are valid.
        """
        ...

    def PhotoFilter(self, FillColor, Density, PreserveLuminosity) -> None:
        """
        Adjust the layer’s color balance and temperature as if a color filter had been applied (Density: 1 - 100, as a percentage).
        """
        ...

    def Posterize(self, Levels:int) -> None:
        """
        Specifies the number of tonal levels (2 - 255) for each channel and then maps pixels to the closest matching level.
        """
        ...

    def Rasterize(self, Target:PsRasterizeType) -> None:
        """
        Converts the targeted contents in the layer into a flat, raster image.
        """
        ...

    def Resize(self, Horizontal:float, Vertical:float, Anchor:PsAnchorPosition) -> None:
        """
        Resizes the layer to the specified dimensions (as a percentage of its current size) and places it in the specified position.
        """
        ...

    def Rotate(self, Angle:float, Anchor:PsAnchorPosition) -> None:
        """
        Rotates the layer around the specified anchor point.
        """
        ...

    def SelectiveColor(self, SelectionMethod:PsAdjustmentReference, Reds:List[int], Yellows:List[int], Greens:List[int], Cyans:List[int], Blues:List[int], Magentas:List[int], Whites:List[int], Neutrals:List[int], Blacks:List[int]) -> None:
        """
        Modifies the amount of a process color in a specified primary color without affecting the other primary colors. Note:Each color array must have four components.
        """
        ...

    def ShadowHighlight(self, ShadowAmount:int, ShadowWidth:int, ShadowRadius:int, HighlightAmount:int, HighlightWidth:int, HighlightRadius:int, ColorCorrection:int, MidtoneContrast:int, BlackClip:float, WhiteClip:float) -> None:
        """
        Adjusts the range of tones in the image’s Shadows and highlights (ShadowAmount: 0 - 100 as percent; ShadowWidth: 0 - 100 as percent; ShadowRadius: 0 - 2500 in pixels; HighlightAmount: 0 - 100 as percent; HighlightWidth: 0 - 100 as percent; HighlightRadius: 0 - 2500 in pixels; ColorCorrection: -100 - 100; MidtoneContrast: -100 - 100; BlackClip: 0.000 - 50.000; WhiteClip: 0.000 - 50.000).
        """
        ...

    def Threshold(self, Level:int) -> None:
        """
        Converts grayscale or color images to high-contrast, B/W images by converting pixels lighter than the specified threshold to white and pixels darker than the threshold to black (level: 1 - 255).
        """
        ...

    def Translate(self, DeltaX:float, DeltaY:float) -> None:
        """
        Moves the layer the specified amount (in pixels) relative to its current position.
        """
        ...

    def Unlink(self) -> None:
        """
        Unlinks the layer.
        """
        ...





from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from events import *
    from typing import List, Any
    from .pspdfresampletype import PsPDFResampleType
    from .pspdfcompatibilitytype import PsPDFCompatibilityType
    from .application import Application
    from .pspdfencoding import PsPDFEncoding
    from .pspdfstandardtype import PsPDFStandardType

class PDFSaveOptions():
    """
    Options that can be specified when saving a document in PDF format. 
    """
    @property
    def AlphaChannels(self) -> bool:
        """
        Read-write. Indicates whether to save the alpha channels with the file.
        """
        ...

    @property
    def Annotations(self) -> bool:
        """
        Read-write. Indicates whether to save comments with the file.
        """
        ...

    @property
    def Application(self) -> Application:
        """
        Read-only. The application that the object belongs to.
        """
        ...

    @property
    def ColorConversion(self) -> bool:
        """
        Read-write. Indicates whether to convert the color profile to a destination profile.
        """
        ...

    @property
    def ConvertToEightBit(self) -> bool:
        """
        Read-write. Indicates whether to convert a 16-bit image to 8-bit for better compatibility with other applications.
        """
        ...

    @property
    def Descripton(self) -> str:
        """
        Read-write. Description of the save options to use.
        """
        ...

    @property
    def DestinationProfile(self) -> str:
        """
        Read-write. Description of the final RGB or CMYK output device, such as a monitor or a press standard.
        """
        ...

    @property
    def DowngradeColorProfile(self) -> bool:
        """
        Deprecated for Adobe Photoshop.
        """
        ...

    @property
    def DownSample(self) -> PsPDFResampleType:
        """
        Read-write. The down sample method to use.
        """
        ...

    @property
    def DownSampleSize(self) -> float:
        """
        Read-write. The size to downsample images if they exceed the limit in pixels per inch.
        """
        ...

    @property
    def DownSampleSizeLimit(self) -> float:
        """
        Read-write. Limits downsampling or subsampling to images that exceed this value in pixels per inch.
        """
        ...

    @property
    def EmbedColorProfile(self) -> bool:
        """
        Read-write. Indicates whether to embed the color profile in the document.
        """
        ...

    @property
    def EmbedFonts(self) -> bool:
        """
        Deprecated for Adobe Photoshop.
        """
        ...

    @property
    def EmbedThumbnail(self) -> bool:
        """
        Read-write. Indicates whether to include a small preview image in Adobe PDF files.
        """
        ...

    @property
    def Encoding(self) -> PsPDFEncoding:
        """
        Read-write. The encoding method to use. Default: 1 (psPDFZIP).
        """
        ...

    @property
    def Interpolation(self) -> bool:
        """
        Deprecated for Adobe Photoshop.
        """
        ...

    @property
    def JPEGQuality(self) -> int:
        """
        Read-write. The quality of the produced image (0 - 12), which is inversely proportionate to the compression amount. Note:Valid only when Encoding = 2 (psPDFJPEG).
        """
        ...

    @property
    def Layers(self) -> bool:
        """
        Read-write. Indicates whether to save the document’s layers.
        """
        ...

    @property
    def OptimizeForWeb(self) -> bool:
        """
        Read-write. Indicates whether to improve performance of PDF files on Web servers.
        """
        ...

    @property
    def OutputCondition(self) -> str:
        """
        Read-write. An optional comment field for inserting descriptions of the output condition. The text is stored in the PDF/X file.
        """
        ...

    @property
    def OutputConditionID(self) -> str:
        """
        Read-write. Indentifier for the output condition.
        """
        ...

    @property
    def PDFCompatibility(self) -> PsPDFCompatibilityType:
        """
        Read-write. The PDF version to make the document compatible with.
        """
        ...

    @property
    def PDFStandard(self) -> PsPDFStandardType:
        """
        Read-write. The PDF standard to make the document compatible with.
        """
        ...

    @property
    def PreserveEditing(self) -> bool:
        """
        Read-write. Indicates whether to reopen the PDF in Adobe Photoshop with native Photoshop data intact.
        """
        ...

    @property
    def PresetFile(self) -> str:
        """
        Read-write. The preset file to use for settings. Note:This option overrides other settings.
        """
        ...

    @property
    def ProfileInclusionPolicy(self) -> bool:
        """
        Read-write. Indicates whether to show which profiles to include.
        """
        ...

    @property
    def RegistryName(self) -> str:
        """
        Read-write. URL where the output condition is registered.
        """
        ...

    @property
    def SpotColors(self) -> bool:
        """
        Read-write. Indicates whether to save spot colors.
        """
        ...

    @property
    def TileSize(self) -> int:
        """
        Read-write. Compression option. Note:Valid only when encoding = PDFEncoding.JPEG2000.
        """
        ...

    @property
    def Transparency(self) -> bool:
        """
        Deprecated for Adobe Photoshop.
        """
        ...

    @property
    def typename(self) -> str:
        """
        Read-only. The class name of the referenced PDFSaveOptions object.
        """
        ...

    @property
    def UseOutlines(self) -> bool:
        """
        Deprecated for Adobe Photoshop.
        """
        ...

    @property
    def VectorData(self) -> bool:
        """
        Deprecated for Adobe Photoshop.
        """
        ...

    @property
    def View(self) -> bool:
        """
        Read-write. Indicates whether to open the saved PDF in Adobe Acrobat.
        """
        ...

